[comment]: <> (<p align="center">)
[comment]: <> (  <img src="https://github.com/dwreeves/statelit/workflows/tests/badge.svg">)
[comment]: <> (  <img src="https://github.com/dwreeves/statelit/workflows/docs/badge.svg">)
[comment]: <> (</p>)
[comment]: <> (<p align="center">)
[comment]: <> (  <img src="https://raw.githubusercontent.com/dwreeves/statelit/main/docs/src/img/statelit-logo.png">)
[comment]: <> (</p>)
<p align="center">
    <em>Easy state management in Streamlit with Pydantic.</em>
</p>

---

# Work in progress!

This repo is currently a work in progress. Check back soon!

# Trademark & Copyright

Streamlit is a trademark of Streamlit Inc.

This package is **unaffiliated** with Streamlit Inc.
